==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d3/d96/structIndustryCargoesWindow.js <==
var structIndustryCargoesWindow =
[
    [ "Fields", "d3/d96/structIndustryCargoesWindow.html#a27bd0dd938e390b5eb2d18099d050b04", null ],
    [ "IndustryCargoesWindow", "d3/d96/structIndustryCargoesWindow.html#a9d072b8bc89eb9454a422af6a9580ba9", null ],
    [ "CalculatePositionInWidget", "d3/d96/structIndustryCargoesWindow.html#acfc871b9d3c178959c71c78fa65d9be0", null ],
    [ "ComputeCargoDisplay", "d3/d96/structIndustryCargoesWindow.html#aa17678c1c256db627da99a1e2d489668", null ],
    [ "ComputeIndustryDisplay", "d3/d96/structIndustryCargoesWindow.html#a21792045a1bbeeb66052beda8db603fb", null ],
    [ "CountMatchingAcceptingIndustries", "d3/d96/structIndustryCargoesWindow.html#af69079aee847251abe93d52162e5effa", null ],
    [ "CountMatchingProducingIndustries", "d3/d96/structIndustryCargoesWindow.html#ae88fe2728a9c5356625a44d1f0bc40a0", null ],
    [ "DrawWidget", "d3/d96/structIndustryCargoesWindow.html#a3ddcd9e662b1c1fdf3bb841b373b8bc3", null ],
    [ "HasCommonValidCargo", "d3/d96/structIndustryCargoesWindow.html#aa0114f2d5b52fbbad28be7b4f5a10a4e", null ],
    [ "HousesCanAccept", "d3/d96/structIndustryCargoesWindow.html#af28602f116b619ddf0c3c7d09818cff3", null ],
    [ "HousesCanSupply", "d3/d96/structIndustryCargoesWindow.html#a944fdb28a6663a6a7b04db9ee0ea2d90", null ],
    [ "NotifySmallmap", "d3/d96/structIndustryCargoesWindow.html#abd7ea273b919c27323548f945debc6c5", null ],
    [ "OnClick", "d3/d96/structIndustryCargoesWindow.html#a0984346421c22876e4102bdc4f56a4ff", null ],
    [ "OnDropdownSelect", "d3/d96/structIndustryCargoesWindow.html#a185d828172f5fd444d07aec463e9e398", null ],
    [ "OnHover", "d3/d96/structIndustryCargoesWindow.html#a93983551a43771362f9ba94ed2a04221", null ],
    [ "OnInit", "d3/d96/structIndustryCargoesWindow.html#aed9f3065ff90d4ac8461bb90412f0711", null ],
    [ "OnInvalidateData", "d3/d96/structIndustryCargoesWindow.html#abe2a62e5c357b2c0c784e4f3cee92470", null ],
    [ "OnResize", "d3/d96/structIndustryCargoesWindow.html#a5d04bcede6f581fcdc9659e6371d1e4e", null ],
    [ "PlaceIndustry", "d3/d96/structIndustryCargoesWindow.html#a64a655bc8e06d1c9ade7825ed50f21ab", null ],
    [ "SetStringParameters", "d3/d96/structIndustryCargoesWindow.html#a936ccc1d5e0912200650f1f0d225170b", null ],
    [ "ShortenCargoColumn", "d3/d96/structIndustryCargoesWindow.html#a4f8342f20fdd33832dddb3b9b245c0dd", null ],
    [ "UpdateWidgetSize", "d3/d96/structIndustryCargoesWindow.html#a06c3c5eab19842f7e5f1018d4ba8b9ca", null ],
    [ "cargo_textsize", "d3/d96/structIndustryCargoesWindow.html#a0089ad20039ee9211a3d6cee29cbb09c", null ],
    [ "fields", "d3/d96/structIndustryCargoesWindow.html#a9177632faaa8246f3439f114b7f17900", null ],
    [ "HOR_TEXT_PADDING", "d3/d96/structIndustryCargoesWindow.html#a7da84d211da1cf30a321605cabeff365", null ],
    [ "ind_cargo", "d3/d96/structIndustryCargoesWindow.html#ad43ad1aa8d79b593b251e20828fd8be9", null ],
    [ "ind_textsize", "d3/d96/structIndustryCargoesWindow.html#a4cc60672fac18c5ae396a4c2a4b2e314", null ],
    [ "type", "d3/d96/structIndustryCargoesWindow.html#a6e896de9c0076815101c4457b4de592e", null ],
    [ "VERT_TEXT_PADDING", "d3/d96/structIndustryCargoesWindow.html#ae2686c0781081b0f44f68236f78670a9", null ],
    [ "vscroll", "d3/d96/structIndustryCargoesWindow.html#a74f5690363a78a8622bfc64ce84d8cb0", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d3/d96/structIndustryCargoesWindow.js <==
var structIndustryCargoesWindow =
[
    [ "Fields", "d3/d96/structIndustryCargoesWindow.html#a704b97fcb496e707d7d2ff2c9f8b5899", null ],
    [ "IndustryCargoesWindow", "d3/d96/structIndustryCargoesWindow.html#a9d072b8bc89eb9454a422af6a9580ba9", null ],
    [ "CalculatePositionInWidget", "d3/d96/structIndustryCargoesWindow.html#acfc871b9d3c178959c71c78fa65d9be0", null ],
    [ "ComputeCargoDisplay", "d3/d96/structIndustryCargoesWindow.html#aa17678c1c256db627da99a1e2d489668", null ],
    [ "ComputeIndustryDisplay", "d3/d96/structIndustryCargoesWindow.html#a21792045a1bbeeb66052beda8db603fb", null ],
    [ "CountMatchingAcceptingIndustries", "d3/d96/structIndustryCargoesWindow.html#af69079aee847251abe93d52162e5effa", null ],
    [ "CountMatchingProducingIndustries", "d3/d96/structIndustryCargoesWindow.html#ae88fe2728a9c5356625a44d1f0bc40a0", null ],
    [ "DrawWidget", "d3/d96/structIndustryCargoesWindow.html#a5163667bc4c64de6ae304432e09c0f02", null ],
    [ "HasCommonValidCargo", "d3/d96/structIndustryCargoesWindow.html#aa0114f2d5b52fbbad28be7b4f5a10a4e", null ],
    [ "HousesCanAccept", "d3/d96/structIndustryCargoesWindow.html#af28602f116b619ddf0c3c7d09818cff3", null ],
    [ "HousesCanSupply", "d3/d96/structIndustryCargoesWindow.html#a944fdb28a6663a6a7b04db9ee0ea2d90", null ],
    [ "NotifySmallmap", "d3/d96/structIndustryCargoesWindow.html#abd7ea273b919c27323548f945debc6c5", null ],
    [ "OnClick", "d3/d96/structIndustryCargoesWindow.html#ac4ecb045ab121b154dad1b101539776e", null ],
    [ "OnDropdownSelect", "d3/d96/structIndustryCargoesWindow.html#aebfd424b88e2862eaadba8dc2d80defe", null ],
    [ "OnInit", "d3/d96/structIndustryCargoesWindow.html#a32d70f469f014bc50bf9df2f47773968", null ],
    [ "OnInvalidateData", "d3/d96/structIndustryCargoesWindow.html#a107bbbd6b01cfce0c76758f471cc93ec", null ],
    [ "OnResize", "d3/d96/structIndustryCargoesWindow.html#a65efb62f7896dd1b58a12eb614b50bbf", null ],
    [ "OnTooltip", "d3/d96/structIndustryCargoesWindow.html#a253dfc5f7fbd83e188da2cfae3869643", null ],
    [ "PlaceIndustry", "d3/d96/structIndustryCargoesWindow.html#a64a655bc8e06d1c9ade7825ed50f21ab", null ],
    [ "SetStringParameters", "d3/d96/structIndustryCargoesWindow.html#a734b76c7f4fbce537074be0b543138e1", null ],
    [ "ShortenCargoColumn", "d3/d96/structIndustryCargoesWindow.html#a4f8342f20fdd33832dddb3b9b245c0dd", null ],
    [ "UpdateWidgetSize", "d3/d96/structIndustryCargoesWindow.html#a15c33119733f47d3b4d7aa2296bb6c7e", null ],
    [ "cargo_textsize", "d3/d96/structIndustryCargoesWindow.html#a0089ad20039ee9211a3d6cee29cbb09c", null ],
    [ "fields", "d3/d96/structIndustryCargoesWindow.html#a9177632faaa8246f3439f114b7f17900", null ],
    [ "HOR_TEXT_PADDING", "d3/d96/structIndustryCargoesWindow.html#a7da84d211da1cf30a321605cabeff365", null ],
    [ "ind_cargo", "d3/d96/structIndustryCargoesWindow.html#ad43ad1aa8d79b593b251e20828fd8be9", null ],
    [ "ind_textsize", "d3/d96/structIndustryCargoesWindow.html#a4cc60672fac18c5ae396a4c2a4b2e314", null ],
    [ "type", "d3/d96/structIndustryCargoesWindow.html#a6e896de9c0076815101c4457b4de592e", null ],
    [ "VERT_TEXT_PADDING", "d3/d96/structIndustryCargoesWindow.html#ae2686c0781081b0f44f68236f78670a9", null ],
    [ "vscroll", "d3/d96/structIndustryCargoesWindow.html#a74f5690363a78a8622bfc64ce84d8cb0", null ]
];
